/**********************************************************************
 **                                                                  **
 **                             list.cc                              **
 **                                                                  **
 **                                                                  **
 **  This file contains the functions for ListUtility class,         **
 **  which deals the various lists in eBug.                          **
 **                                                                  **
 **  Written by:  Yoichiro Endo (Mobile Robot Lab, Georgia Tech)     **
 **                                                                  **
 **  Copyright 2000 Georgia Tech Research Corporation                **
 **  Atlanta, Georgia  30332-0415                                    **
 **  ALL RIGHTS RESERVED, See file COPYRIGHT for details.            **
 **                                                                  **
 **********************************************************************/

/* $Id: list.cc,v 1.5 2000/10/25 04:45:27 endo Exp $ */

#include "ebug.h"

//-----------------------------------------------------------------------------
// ListUtility is a class which is a collection of functions that deal with
// lists in eBug.
//-----------------------------------------------------------------------------
ListUtility::ListUtility()
{
}

//-----------------------------------------------------------------------------
// This function adds the data in the list.
//-----------------------------------------------------------------------------
void ListUtility::push(struct t_node **list, int *data)
{
  struct t_node *tmp_node;

  tmp_node = (t_node *)malloc(sizeof(struct t_node));
  (*tmp_node).next = *list;
  (*tmp_node).data = data;
  *list = tmp_node;
}

//-----------------------------------------------------------------------------
// This function deletes the list contents.
//-----------------------------------------------------------------------------
void ListUtility::clearList(struct t_node **list)
{
  struct t_node *p,*po;

  p = *list;
  if ((*p).data == NULL) return;

  do {
    po = p;
    p = (*p).next;
    free(po);
  } while ((*p).next != NULL);

  *list = p;
}

//-----------------------------------------------------------------------------
// This function creates a list.
//-----------------------------------------------------------------------------
void ListUtility::create(t_node **list)
{
  struct t_node *tmp_node;

  tmp_node = (t_node *)malloc(sizeof(t_node));
  (*tmp_node).next = NULL;
  (*tmp_node).data = NULL;
  *list = tmp_node;
}

/**********************************************************************
 * $Log: list.cc,v $
 * Revision 1.5  2000/10/25 04:45:27  endo
 * Code cleaned up for the distribution.
 *
 * Revision 1.4  2000/08/19 20:46:29  endo
 * Slight changes due to the hardware interface.
 *
 * Revision 1.3  2000/08/06 07:27:33  endo
 * Two light types implemented successfully.
 *
 * Revision 1.2  2000/07/31 05:32:52  endo
 * Clean up.
 *
 * Revision 1.1  2000/03/26 08:38:43  endo
 * Initial revision
 *
 *
 **********************************************************************/


