/**********************************************************************
 **                                                                  **
 **                              log.cc                              **
 **                                                                  **
 **                                                                  **
 **  This file contains the functions for LogUtility class,          **
 **  which deals with the logging experimental data.                 **
 **                                                                  **
 **  Written by:  Yoichiro Endo (Mobile Robot Lab, Georgia Tech)     **
 **                                                                  **
 **  Copyright 2000 Georgia Tech Research Corporation                **
 **  Atlanta, Georgia  30332-0415                                    **
 **  ALL RIGHTS RESERVED, See file COPYRIGHT for details.            **
 **                                                                  **
 **********************************************************************/

/* $Id: log.cc,v 1.3 2000/10/25 05:43:02 endo Exp endo $ */

#include "ebug.h"

FILE *logfile;

//-----------------------------------------------------------------------------
// LogUtility is a class which is a collection of functions that deal with
// logging experiental data.
//-----------------------------------------------------------------------------
LogUtility::LogUtility()
{
}

//-----------------------------------------------------------------------------
// This function initializes the log file.
//-----------------------------------------------------------------------------
void LogUtility::initializeLogFile(void)
{
  TimeUtility time_utility;

  logfile = fopen(log_filename, "a");

  char *today = time_utility.currentDate();
  int pid = getpid();

  fprintf(logfile, "Data-%s-%d: trial, age, id, x, y, progression, angvel, vte, hypotheis (A, B), orientation need (A, B)\n",
	  today, pid);
  fflush(logfile);
}

//-----------------------------------------------------------------------------
// This function records the performance of the robot.
//-----------------------------------------------------------------------------
void LogUtility::recordPerformance(void)
{
  if (robotList->data == NULL) return;

  t_node *pr = robotList;
  while (pr->next != NULL)
  {
    t_robot *robot = (t_robot*)pr->data;

    fprintf(logfile, "%d %f %d %f %f %f %f %d %f %f %f %f\n",
	    trial, age, robot->id, robot->x, robot->y, robot->progression, robot->angvel, robot->vte,
	    robot->hypothesis[TYPE_A], robot->hypothesis[TYPE_B],
	    robot->orientation_need[TYPE_A], robot->orientation_need[TYPE_B]);

    pr = pr->next;
  }
  fflush(logfile);
}

//-----------------------------------------------------------------------------
// This function close the log file.
//-----------------------------------------------------------------------------
void LogUtility::closeLogFile(void)
{
  fclose(logfile);
}

/**********************************************************************
 * $Log: log.cc,v $
 * Revision 1.3  2000/10/25 05:43:02  endo
 * Minor change.
 *
 * Revision 1.2  2000/10/25 04:45:27  endo
 * Code cleaned up for the distribution.
 *
 * Revision 1.1  2000/08/19 20:42:12  endo
 * Initial revision
 *
 *
 **********************************************************************/
