/**********************************************************************
 **                                                                  **
 **                              time.cc                             **
 **                                                                  **
 **                                                                  **
 **  Thus file contains the functions for TimeUtility class, which   **
 **  deals with time related issues.                                 **
 **                                                                  **
 **  Written by:  Yoichiro Endo (Mobile Robot Lab, Georgia Tech)     **
 **                                                                  **
 **  Copyright 2000 Georgia Tech Research Corporation                **
 **  Atlanta, Georgia  30332-0415                                    **
 **  ALL RIGHTS RESERVED, See file COPYRIGHT for details.            **
 **                                                                  **
 **********************************************************************/

/* $Id: time.cc,v 1.4 2000/10/25 04:45:27 endo Exp $ */

#include "ebug.h"

double age = 0.0;
double delta_time = 0.0; 

//-----------------------------------------------------------------------------
// TimeUtility is a class which is a collection of functions that deal with
// time related issues in eBug.
//-----------------------------------------------------------------------------
TimeUtility::TimeUtility()
{
}

//-----------------------------------------------------------------------------
// This function returns current date as a string.
//-----------------------------------------------------------------------------
char* TimeUtility::currentDate(void)
{
  // Getting the date of a year in order to append
  // it to the file name.
  char month[100];
  char date[100];
  char year[100];
  const time_t cur_time = time(NULL);
  tm local_time = *localtime(&cur_time);

  strftime(month,sizeof(month), "%m", &local_time);
  strftime(date,sizeof(date), "%d", &local_time);
  strftime(year,sizeof(year), "%Y", &local_time);

  char rtn_date[300];
  sprintf(rtn_date, "%s/%s/%s", month, date, year);

  return strdup(rtn_date);
}

//-----------------------------------------------------------------------------
// This function returns current time as double.
//-----------------------------------------------------------------------------
double TimeUtility::currentTime(void)
{
  timeval tvp;
  double  cur_time;

  gettimeofday( &tvp, NULL );
  cur_time = (double)tvp.tv_sec + ((double)tvp.tv_usec)/1000000.0;;

  return cur_time;
}

//-----------------------------------------------------------------------------
// This function calculates the age of the robot.
//-----------------------------------------------------------------------------
void TimeUtility::computeAge(void)
{
  double current_time = currentTime();
  double duration = current_time - birth_time;

  static double last_time = current_time;
  delta_time = current_time - last_time;

  static double paused_period = 0.0, last_duration = 0.0;

  if (!go)
    paused_period += duration - last_duration;

  age = duration - paused_period;
  
  last_time = current_time;
  last_duration = duration;
}

//-----------------------------------------------------------------------------
// This function makes the program to sleep for specified time (in second).
//-----------------------------------------------------------------------------
void TimeUtility::nap(double nap_time)
{
  // Get the start time.
  static timeval start_time = {0,0};
  
  // when do we want to release?
  timeval end_time = start_time;
  end_time.tv_usec += (const long)(nap_time*1000000);
  if( end_time.tv_usec >= 1000000 )
  {
      end_time.tv_sec  += end_time.tv_usec / 1000000;
      end_time.tv_usec  = end_time.tv_usec % 1000000;
  }

  timeval now_time;
  int rtn;
  if((rtn = gettimeofday(&now_time, NULL)) != 0)
    fprintf(stderr, "Error: gettimeofday returned %d\n", rtn);
      
  // If we are ahead of schedule, then wait around a bit.
  else if( timercmp(&now_time, &end_time, <) ) 
  {
    // How far away is the release time in microseconds?
    long yet_to_wait = (end_time.tv_sec - now_time.tv_sec) * 1000000;
    yet_to_wait += (long)end_time.tv_usec - (long)now_time.tv_usec;
	  
    // Don't sleep if less than a millisecond.
    if( yet_to_wait > 1000 )
    {
      // Wait for that long before starting the next cycle.
      usleep(yet_to_wait);
    }
  }
}

/**********************************************************************
 * $Log: time.cc,v $
 * Revision 1.4  2000/10/25 04:45:27  endo
 * Code cleaned up for the distribution.
 *
 * Revision 1.3  2000/08/19 20:46:29  endo
 * Slight changes due to the hardware interface.
 *
 * Revision 1.2  2000/08/10 06:16:34  endo
 * delta_time added.
 *
 * Revision 1.1  2000/07/29 22:18:56  endo
 * Initial revision
 *
 *
 **********************************************************************/
